# Color Pecker
<img src="colorpecker/resources/logo.png" style="float:left; margin-right:20px;" />
A Python based color picker written with PySide6 and QT. Can be used as a stand-alone as a more modern color picker utility or easily imported and used within your existing QT application. It's cross platform and tested on Windows and Linux.

